# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.0 Python SDK

    Pure Storage FlashBlade REST 1.0 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.0
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot0
from purity_fb_1dot0.rest import ApiException
from purity_fb_1dot0.apis.file_system_snapshots_api import FileSystemSnapshotsApi


class TestFileSystemSnapshotsApi(unittest.TestCase):
    """ FileSystemSnapshotsApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot0.apis.file_system_snapshots_api.FileSystemSnapshotsApi()

    def tearDown(self):
        pass

    def test_create_file_system_snapshots(self):
        """
        Test case for create_file_system_snapshots

        
        """
        pass

    def test_list_file_system_snapshots(self):
        """
        Test case for list_file_system_snapshots

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
