# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot10
from purity_fb_1dot10.rest import ApiException
from purity_fb_1dot10.apis.syslog_api import SyslogApi


class TestSyslogApi(unittest.TestCase):
    """ SyslogApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot10.apis.syslog_api.SyslogApi()

    def tearDown(self):
        pass

    def test_create_syslog_servers(self):
        """
        Test case for create_syslog_servers

        
        """
        pass

    def test_delete_syslog_servers(self):
        """
        Test case for delete_syslog_servers

        
        """
        pass

    def test_list_syslog_servers(self):
        """
        Test case for list_syslog_servers

        
        """
        pass

    def test_list_syslog_settings(self):
        """
        Test case for list_syslog_settings

        
        """
        pass

    def test_test_syslog_config(self):
        """
        Test case for test_syslog_config

        
        """
        pass

    def test_update_syslog_servers(self):
        """
        Test case for update_syslog_servers

        
        """
        pass

    def test_update_syslog_settings(self):
        """
        Test case for update_syslog_settings

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
