# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot12
from purity_fb_1dot12.rest import ApiException
from purity_fb_1dot12.apis.object_store_access_policies_api import ObjectStoreAccessPoliciesApi


class TestObjectStoreAccessPoliciesApi(unittest.TestCase):
    """ ObjectStoreAccessPoliciesApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot12.apis.object_store_access_policies_api.ObjectStoreAccessPoliciesApi()

    def tearDown(self):
        pass

    def test_add_object_store_access_policies_object_store_users(self):
        """
        Test case for add_object_store_access_policies_object_store_users

        
        """
        pass

    def test_list_object_store_access_policies(self):
        """
        Test case for list_object_store_access_policies

        
        """
        pass

    def test_list_object_store_access_policies_object_store_users(self):
        """
        Test case for list_object_store_access_policies_object_store_users

        
        """
        pass

    def test_remove_object_store_access_policies_object_store_users(self):
        """
        Test case for remove_object_store_access_policies_object_store_users

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
