# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.5 Python SDK

    Pure Storage FlashBlade REST 1.5 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.5
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot5
from purity_fb_1dot5.rest import ApiException
from purity_fb_1dot5.apis.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """ PoliciesApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot5.apis.policies_api.PoliciesApi()

    def tearDown(self):
        pass

    def test_create_policies(self):
        """
        Test case for create_policies

        
        """
        pass

    def test_create_policy_filesystems(self):
        """
        Test case for create_policy_filesystems

        
        """
        pass

    def test_delete_policies(self):
        """
        Test case for delete_policies

        
        """
        pass

    def test_delete_policy_filesystems(self):
        """
        Test case for delete_policy_filesystems

        
        """
        pass

    def test_list_policies(self):
        """
        Test case for list_policies

        
        """
        pass

    def test_list_policy_filesystem_snapshots(self):
        """
        Test case for list_policy_filesystem_snapshots

        
        """
        pass

    def test_list_policy_filesystems(self):
        """
        Test case for list_policy_filesystems

        
        """
        pass

    def test_list_policy_members(self):
        """
        Test case for list_policy_members

        
        """
        pass

    def test_update_policies(self):
        """
        Test case for update_policies

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
